@@ -1,6 +1,6 @@
 /*
  * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
  *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
  * 
  * This file is part of the Notre Dame LAM implementation of MPI.
@@ -10,18 +10,21 @@
  * LICENSE.  If not, contact Office of Research, University of Notre
  * Dame, Notre Dame, IN 46556.
  * 
- * Permission to modify the code and to distribute modified code is
- * granted, provided the text of this NOTICE is retained, a notice that
- * the code was modified is included with the above COPYRIGHT NOTICE and
- * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
- * file is distributed with the modified code.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted subject to the conditions specified in the
+ * LICENSE file.
  * 
- * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
- * By way of example, but not limitation, Licensor MAKES NO
- * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
- * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
- * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
+ * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+ * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
+ * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
+ * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  * 
  * Additional copyrights may follow.
  * 
@@ -29,7 +32,7 @@
  *	Copyright 1997 The Ohio State University
  *	RBD/NJN
  *
- *	$Id: mpirun.c,v 6.43 2001/03/23 19:53:22 jsquyres Exp $
+ *	$Id: mpirun.c,v 6.43.2.1 2001/10/07 17:14:27 bbarrett Exp $
  *
  *	Function:	- start an MPI application
  */
@@ -86,10 +89,11 @@ static void reset_stdio(void);
 static void sigint_handler(int sig);
 static LIST *build_app(int argc, char **argv, char **env);
 static char *locate_aschema(char *filename);
-static void node_ranges(char *buf, int4 initnode, int4 initindex);
+static void node_ranges(char **buf, int4 *len, int4 initnode, int4 initindex);
 static int get_mpi_world(int4 world_n, struct _gps *world, 
 			 struct _gps *mpiworld);
 static void error_cleanup(void);
+static void str_append(char **src, int *len, char *suffix);
 #if LAM_WANT_IMPI
 static int send_impi_params(struct _gps *);
 #endif
@@ -459,19 +463,20 @@ build_app(int argc, char **argv, char **env)
 		fmtbuf[0] = 0;
 
 		if (fl_nprocs) {
-			sprintf(smallbuf, "-c %d ", nprocs);
-			strcat(fmtbuf, smallbuf);
+		  sprintf(smallbuf, "-c %d ", nprocs);
+		  str_append(&fmtbuf, &fmtbuf_len, smallbuf);
 		}
 
 		if (ao_taken(ad, "s")) {
-			strcat(fmtbuf, "-s ");
-			strcat(fmtbuf, ao_param(ad, "s", 0, 0));
-			strcat(fmtbuf, " ");
+		  str_append(&fmtbuf, &fmtbuf_len, "-s ");
+		  str_append(&fmtbuf, &fmtbuf_len, ao_param(ad, "s", 0, 0));
+		  str_append(&fmtbuf, &fmtbuf_len, " ");
 		}
 
 		if (index == 0) {
-			if (nodeid == LOCAL) nodeid = getnodeid();
-			node_ranges(fmtbuf, nodeid, index);
+		  if (nodeid == LOCAL) 
+		    nodeid = getnodeid();
+		  node_ranges(&fmtbuf, &fmtbuf_len, nodeid, index);
 		}
 
 		for (--argc, ++argv; argc > 0; --argc, ++argv) {
@@ -483,25 +488,15 @@ build_app(int argc, char **argv, char **env)
 
 			/* Oh for STL strings... */
 
-			if (strlen(fmtbuf) + strlen(qarg) + 1 > 
-			    fmtbuf_len) {
-			  fmtbuf_len *= 2;
-			  fmtbuf = realloc(fmtbuf, fmtbuf_len);
-			}
-			strcat(fmtbuf, qarg);
-			strcat(fmtbuf, " ");
+			str_append(&fmtbuf, &fmtbuf_len, qarg);
+			str_append(&fmtbuf, &fmtbuf_len, " ");
 			free(qarg);
 		}
 
 		ao_tail(ad, &argtailc, &argtailv);
 
-		/* Oh for STL strings... */
-		
-		if (strlen(fmtbuf) + 3 > fmtbuf_len) {
-		  fmtbuf_len *= 2;
-		  fmtbuf = realloc(fmtbuf, fmtbuf_len);
-		}
-		if (argtailc > 0) strcat(fmtbuf, "-- ");
+		if (argtailc > 0) 
+		  str_append(&fmtbuf, &fmtbuf_len, "-- ");
 
 		for ( ; argtailc > 0; --argtailc, ++argtailv) {
 			qarg = sfh_argv_quote(*argtailv, "\\'\"");
@@ -510,15 +505,8 @@ build_app(int argc, char **argv, char **env)
 				return(0);
 			}
 
-			/* Oh for STL strings... */
-
-			if (strlen(fmtbuf) + strlen(qarg) + 1 > 
-			    fmtbuf_len) {
-			  fmtbuf_len *= 2;
-			  fmtbuf = realloc(fmtbuf, fmtbuf_len);
-			}
-			strcat(fmtbuf, qarg);
-			strcat(fmtbuf, " ");
+			str_append(&fmtbuf, &fmtbuf_len, qarg);
+			str_append(&fmtbuf, &fmtbuf_len, " ");
 			free(qarg);
 		}
 /*
@@ -801,7 +789,7 @@ locate_aschema(char *filename)
  *			- initial index
  */
 static void
-node_ranges(char *buf, int4 initnode, int4 initindex)
+node_ranges(char **buf, int *len, int4 initnode, int4 initindex)
 {
 	int4		node;			/* target node */
 	int4		index;			/* for getnode() */
@@ -810,7 +798,7 @@ node_ranges(char *buf, int4 initnode, int4 initindex)
 	int		fl_flush = 0;		/* flush node flag */
 
 	sprintf(smallbuf, "n%d", initnode);
-	strcat(buf, smallbuf);
+	str_append(buf, len, smallbuf);
 /*
  * Loop over the nodes.
  */
@@ -825,14 +813,14 @@ node_ranges(char *buf, int4 initnode, int4 initindex)
  * We have a "hole" ending a range of length >= 2.
  */
 				sprintf(smallbuf, "-%d,%d", next - 1, node);
-				strcat(buf, smallbuf);
+				str_append(buf, len, smallbuf);
 			}
 			else {
 /*
  * We have a "hole" ending a range of length 1.
  */
 				sprintf(smallbuf, ",%d", node);
-				strcat(buf, smallbuf);
+				str_append(buf, len, smallbuf);
 			}
 			initnode = node;
 			next = node + 1;
@@ -853,10 +841,10 @@ node_ranges(char *buf, int4 initnode, int4 initindex)
  */
 	if (fl_flush) {
 		sprintf(smallbuf, "-%d", next - 1);
-		strcat(buf, smallbuf);
+		str_append(buf, len, smallbuf);
 	}
 
-	strcat(buf, " ");
+	str_append(buf, len, " ");
 }
 
 /*
@@ -979,6 +967,28 @@ error_cleanup(void)
 }
 
 
+/*
+ * Safely append to a string.  Of for STL strings...
+ */
+static void
+str_append(char **src, int *len, char *suffix)
+{
+  int slen1;
+  int slen2;
+
+  slen1 = strlen(*src);
+  slen2 = strlen(suffix);
+
+  if (slen1 + slen2 > *len) {
+    while (slen1 + slen2 > *len)
+      *len *= 2;
+    *src = realloc(*src, *len);
+  }
+
+  strcat(*src, suffix);
+}
+
+
 #if LAM_WANT_IMPI
 static int
 send_impi_params(struct _gps *world)
