@@ -1,6 +1,6 @@
 /*
  * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
  *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
  * 
  * This file is part of the Notre Dame LAM implementation of MPI.
@@ -10,18 +10,21 @@
  * LICENSE.  If not, contact Office of Research, University of Notre
  * Dame, Notre Dame, IN 46556.
  * 
- * Permission to modify the code and to distribute modified code is
- * granted, provided the text of this NOTICE is retained, a notice that
- * the code was modified is included with the above COPYRIGHT NOTICE and
- * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
- * file is distributed with the modified code.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted subject to the conditions specified in the
+ * LICENSE file.
  * 
- * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
- * By way of example, but not limitation, Licensor MAKES NO
- * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
- * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
- * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
+ * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+ * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
+ * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
+ * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  * 
  * Additional copyrights may follow.
  * 
@@ -29,7 +32,7 @@
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: kernelio.c,v 6.13 2000/12/06 14:35:21 jsquyres Exp $
+ *	$Id: kernelio.c,v 6.13.2.1 2001/10/16 15:21:59 jsquyres Exp $
  * 
  *	Function:	- receives kernel requests and send replies
  *			- moves messages between clients
@@ -71,18 +74,21 @@
 /*
  * global functions
  */
-struct kreq		*kio_req();		/* request from client */
-void			kio_cleanup();		/* free resources */
-void			kio_close();		/* close connection */
-void			kio_init();		/* initialize */
-void			kio_intr();		/* register interrupt */
-void			kio_intr_clr();		/* clear interrupt */
-void			kio_reply();		/* reply to client */
-void			kio_send();		/* send from internal proc */
-void			kio_transfer();		/* move msg, ext to ext */
-int			kio_fd_ready();		/* get fd_ready */
-int			kio_recv();		/* recv to internal proc */
-int			kio_to();		/* register timeout */
+struct kreq *kio_req(void);                     /* request from client */
+void kio_cleanup(void);                         /* free resources */
+void kio_close(int fd_client);                  /* close connection */
+void kio_init(void);                            /* initialize */
+void kio_intr(int fd, void (*f)(), int bclear); /* register interrupt */
+void kio_intr_clr(int fd);                      /* clear interrupt */
+void kio_reply(struct kreply *rep, int4 fd_clnt); /* reply to client */
+void kio_send(struct kmsg *sendkmsg, int4 minlen, int fd_client);
+                                                /* send from internal proc */
+void kio_transfer(struct kmsg *sendkmsg, int fd_send, int fd_recv, 
+		  int4 minlen);                 /* move msg, ext to ext */
+int kio_fd_ready(void);                         /* get fd_ready */
+int kio_recv(struct kmsg *recvkmsg, int4 minlen, int fd_client); 
+                                                /* recv to internal proc */
+int kio_to(struct timeval *delay, void (*f)()); /* register timeout */
 
 /*
  * external functions
@@ -145,7 +151,6 @@ static void		kio_shutdown();		/* cleanup and exit */
  */
 void
 kio_init()
-
 {
 	char		*f_kill;		/* kill filename */
 	char		*f_sock;		/* socket filename */
@@ -170,7 +175,7 @@ kio_init()
  * I want to return an error on a broken connection.
  */
 	if (_lam_signal(SIGPIPE, SIG_IGN) == SIG_ERR)
-			lampanic("kernel (_lam_signal)");
+	  lampanic("lamd kernel: problem with internal call _lam_signal() (1)");
 /*
  * Set up local address.
  */
@@ -182,39 +187,48 @@ kio_init()
  * Create the socket.
  */
 	if ((sd_kernel = socket(AF_UNIX, SOCK_STREAM, 0)) < 0)
-			lampanic("kernel (socket)");
+	  lampanic("lamd kernel: problem with socket()");
 
 	fd_max = sd_kernel;
 /*
  * Bind the kernel's address to the socket.
  */
 	if (bind(sd_kernel, (localaddr_t) &kernel_un, sizeof(kernel_un) -
-				sizeof(kernel_un.sun_path) + strlen(f_sock)))
-		lampanic("kernel (bind)");
+		 sizeof(kernel_un.sun_path) + strlen(f_sock))) {
+	  if (errno == EACCES) {
+	    fprintf(stderr, "lamd kernel: permission denied trying to bind to the named socket:\n");
+	    fprintf(stderr, "lamd kernel: \"%s\"\n", kernel_un.sun_path);
+	    fprintf(stderr, "lamd kernel: check the unix permissions");
+	    lampanic("lamd kernel");
+	  } else
+	    lampanic("lamd kernel: problem with bind()");
+	}
 	free(f_sock);
 /*
  * Establish backlog queue.
  */
-	if (listen(sd_kernel, 5)) lampanic("kernel (listen)");
+	if (listen(sd_kernel, 5)) 
+	  lampanic("lamd kernel: problem with listen()");
 /*
  * Open the kill record file.
  */
-	if ((f_kill = killname()) == 0) lampanic("kernel (killname)");
+	if ((f_kill = killname()) == 0) 
+	  lampanic("lamd kernel: problem with internal call killname()");
 
 	if (kkillopen(f_kill)) {
-		fprintf(stderr, "kernel (kkillopen): %s: ", f_kill);
-		lampanic("");
+	  fprintf(stderr, "lamd kernel: problem with internal call kkillopen(): %s: ", f_kill);
+	  lampanic("");
 	}
 	free(f_kill);
 /*
  * Catch SIGTERM and SIGINT and kill all attached processes.
  */
 	if (_lam_signal(SIGTERM, kio_shutdown) == SIG_ERR)
-			lampanic("kernel (_lam_signal)");
+	  lampanic("lamd kernel: problem with internal call _lam_signal() (2)");
 
 	if (_lam_signal(SIGINT, kio_shutdown) == SIG_ERR)
-			lampanic("kernel (_lam_signal)");
-
+	  lampanic("lamd kernel: problem with internal call _lam_signal() (3)");
+	
 	FD_ZERO(&allfds);
 	FD_ZERO(&clientfds);
 	nfd_ready = 0;
@@ -229,7 +243,6 @@ kio_init()
  */
 struct kreq *
 kio_req()
-
 {
 	int		i;
 	LAM_SOCK_OPTLEN_T length;
@@ -267,7 +280,8 @@ kio_req()
 		while (((nfd_ready = select(fd_max + 1, &readfds,
 			(fd_set *) 0, (fd_set *) &exceptfds, pto)) < 0) &&
 			(errno == EINTR));
-		if (nfd_ready < 0) lampanic("kernel (select)");
+		if (nfd_ready < 0) 
+		  lampanic("lamd kernel: problem with select() (1)");
 /*
  * The actual timeout expired.
  */
@@ -291,7 +305,8 @@ kio_req()
 		    length = sizeof(client_un.sun_path);
 		    sd_new = accept(sd_kernel, (localaddr_t) &client_un,
 			    &length);
-		    if (sd_new < 0) lampanic("kernel (accept)");
+		    if (sd_new < 0) 
+		      lampanic("lamd kernel: problem with accept()");
 		    nfd_ready--;
 		    FD_SET(sd_new, &allfds);
 		    FD_SET(sd_new, &clientfds);
@@ -305,16 +320,16 @@ kio_req()
  */
 		    if (sfh_sock_set_buf_size(sd_new, SFH_UNIX, SO_SNDBUF,
 			    	KPKTLEN + sizeof(struct nmsg))) {
-			lampanic("kernel (sfh_sock_set_buf_size)");
+		      lampanic("lamd kernel: problem with internal call sfh_sock_set_buf_size() (1)");
 		    }
 
 		    if (sfh_sock_set_buf_size(sd_new, SFH_UNIX, SO_RCVBUF,
 			    	KPKTLEN + sizeof(struct nmsg))) {
-			lampanic("kernel (sfh_sock_set_buf_size)");
+		      lampanic("lamd kernel: problem with internal call sfh_sock_set_buf_size() (2)");
 		    }
 
 		    if (fcntl(sd_new, F_SETFD, 1) == -1) {
-			lampanic("kernel (fcntl)");
+		      lampanic("lamd kernel: problem with fcntl()");
 		    }
 		}
 	    }
@@ -323,10 +338,12 @@ kio_req()
  */
 	    while ((! FD_ISSET(fd_ready, &readfds)) &&
 		    (! FD_ISSET(fd_ready, &exceptfds))) {
-		fd_ready++;
+	      ++fd_ready;
 	    }
-
-	    nfd_ready--;
+	    if (FD_ISSET(fd_ready, &readfds))
+	      --nfd_ready;
+	    if (FD_ISSET(fd_ready, &exceptfds))
+	      --nfd_ready;
 /*
  * Clean up errnoneous descriptor.
  */
@@ -340,7 +357,7 @@ kio_req()
 	    else if (FD_ISSET(fd_ready, &clientfds)) {
 
 		if (mread(fd_ready, (char *) &request, sizeof(struct kreq)) <
-			sizeof(struct kreq)) {
+			(int)sizeof(struct kreq)) {
 		    knuke(kpfindport(fd_ready));
 		    kio_close(fd_ready);
 		} else {
@@ -356,7 +373,7 @@ kio_req()
 
 		if (i >= KIMAX) {
 		    errno = EIMPOSSIBLE;
-		    lampanic("kernel (select)");
+		    lampanic("lamd kernel: problem with select() (2)");
 		}
 
 		prun = kintrs[i].kn_client;
@@ -380,11 +397,7 @@ kio_req()
  *	Accepts:	- client socket
  */
 void
-kio_reply(reply, fd_client)
-
-struct kreply		*reply;
-int4			fd_client;
-
+kio_reply(struct kreply *reply, int4 fd_client)
 {
 	mwrite(fd_client, (char *) reply, sizeof(struct kreply));
 }
@@ -398,12 +411,7 @@ int4			fd_client;
  *			- clear interrupt after trigger?
  */
 void
-kio_intr(fd, func, bclear)
-
-int			fd;
-void			(*func)();
-int			bclear;
-
+kio_intr(int fd, void (*func)(), int bclear)
 {
 	int		i;
 
@@ -412,7 +420,7 @@ int			bclear;
 
 	if (i >= KIMAX) {
 		errno = EFULL;
-		lampanic("kernel (kio_intr)");
+		lampanic("lamd kernel: problem with internal call kio_intr()");
 	}
 
 	kintrs[i].kn_fd = fd;
@@ -434,10 +442,7 @@ int			bclear;
  *	Accepts:	- interrupt fd
  */
 void
-kio_intr_clr(fd)
-
-int			fd;
-
+kio_intr_clr(int fd)
 {
 	int		i;
 
@@ -459,11 +464,7 @@ int			fd;
  *	Returns:	- 0
  */
 int
-kio_to(delay, func)
-
-struct timeval		*delay;
-void			(*func)();
-
+kio_to(struct timeval *delay, void (*func)())
 {
 	tofunc = func;
 
@@ -485,12 +486,7 @@ void			(*func)();
  *			- send client socket
  */
 int
-kio_recv(recvkmsg, minlen, fd_client)
-
-struct kmsg		*recvkmsg;
-int4			minlen;
-int			fd_client;
-
+kio_recv(struct kmsg *recvkmsg, int4 minlen, int fd_client)
 {
 	struct iovec	iov[2];			/* scatter vectors */
 	char		*sv_msg;
@@ -502,7 +498,7 @@ int			fd_client;
 		iov[1].iov_base = ((struct nmsg *) (recvkmsg->k_msg))->nh_msg;
 		iov[1].iov_len = minlen;
 
-		if (mreadv(fd_client, iov, 2) < (iov[0].iov_len +
+		if (mreadv(fd_client, iov, 2) < (int)(iov[0].iov_len +
 				iov[1].iov_len)) return(LAMERROR);
 		((struct nmsg *) (recvkmsg->k_msg))->nh_msg = sv_msg;
 	} else {
@@ -523,12 +519,7 @@ int			fd_client;
  *			- receive client socket
  */
 void
-kio_send(sendkmsg, minlen, fd_client)
-
-struct kmsg		*sendkmsg;
-int4			minlen;
-int			fd_client;
-
+kio_send(struct kmsg *sendkmsg, int4 minlen, int fd_client)
 {
 	struct iovec	iov[2];			/* scatter vectors */
 
@@ -554,13 +545,7 @@ int			fd_client;
  *			- minimum message length
  */
 void
-kio_transfer(sendkmsg, fd_send, fd_recv, minlen)
-
-struct kmsg		*sendkmsg;
-int			fd_send;
-int			fd_recv;
-int4			minlen;
-
+kio_transfer(struct kmsg *sendkmsg, int fd_send, int fd_recv, int4 minlen)
 {
 	int4		remain;			/* remaining length */
 	int4		len;			/* packet length */
@@ -588,10 +573,7 @@ int4			minlen;
  *	Accepts:	- client socket
  */
 void
-kio_close(fd_client)
-
-int			fd_client;
-
+kio_close(int fd_client)
 {
 	shutdown(fd_client, 2);
 	close(fd_client);
@@ -606,7 +588,6 @@ int			fd_client;
  */
 int
 kio_fd_ready()
-
 {
 	return(fd_ready);
 }
@@ -618,7 +599,6 @@ kio_fd_ready()
  */
 static void
 kio_shutdown()
-
 {
 	kkillall();
 	shutdown(sd_kernel, 2);
@@ -633,7 +613,6 @@ kio_shutdown()
  */
 void
 kio_cleanup()
-
 {
 	close(sd_kernel);
 }
