@@ -1,5 +1,5 @@
 /* 
- *   $Id: ad_hfs_open.c,v 1.1.1.1 1999/03/17 18:52:53 jsquyres Exp $    
+ *   $Id: ad_hfs_open.c,v 1.1.1.1 2000/09/06 20:01:54 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -10,6 +10,9 @@
 void ADIOI_HFS_Open(ADIO_File fd, int *error_code)
 {
     int perm, old_mask, amode;
+#ifndef PRINT_ERR_MSG
+    static char myname[] = "ADIOI_HFS_OPEN";
+#endif
 
     if (fd->perm == ADIO_PERM_NULL) {
 	old_mask = umask(022);
@@ -34,16 +37,23 @@ void ADIOI_HFS_Open(ADIO_File fd, int *error_code)
 
     if ((fd->fd_sys != -1) && (fd->access_mode & ADIO_APPEND)) {
 	fd->fp_ind = lseek64(fd->fd_sys, 0, SEEK_END);
-#ifdef __HPUX
+#ifdef HPUX
 	fd->fp_sys_posn = fd->fp_ind;
 #endif
-#ifdef __SPPUX
-	fd->fp_sys_posn = -1;  /* set it to null bec. we use pread, pwrite*/
-#endif
-	MPI_Barrier(fd->comm);
-	/* the barrier ensures that no process races ahead and modifies
-           the file size before all processes have opened the file. */
     }
 
+#ifdef SPPUX
+	fd->fp_sys_posn = -1;  /* set it to null bec. we use pread, pwrite*/
+#endif
+
+#ifdef PRINT_ERR_MSG
     *error_code = (fd->fd_sys == -1) ? MPI_ERR_UNKNOWN : MPI_SUCCESS;
+#else
+    if (fd->fd_sys == -1) {
+	*error_code = MPIR_Err_setmsg(MPI_ERR_IO, MPIR_ADIO_ERROR,
+			      myname, "I/O Error", "%s", strerror(errno));
+	ADIOI_Error(ADIO_FILE_NULL, *error_code, myname);	    
+    }
+    else *error_code = MPI_SUCCESS;
+#endif
 }
