@@ -1,5 +1,5 @@
 /* 
- *   $Id: ad_hfs_wait.c,v 1.1.1.1 1999/03/17 18:52:53 jsquyres Exp $    
+ *   $Id: ad_hfs_wait.c,v 1.1.1.1 2000/09/06 20:01:54 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -14,12 +14,13 @@ void ADIOI_HFS_ReadComplete(ADIO_Request *request, ADIO_Status *status, int *err
         return;
     }
 
+#ifdef HAVE_STATUS_SET_BYTES
+    MPIR_Status_set_bytes(status, (*request)->datatype, (*request)->nbytes);
+#endif
     (*request)->fd->async_count--;
     ADIOI_Free_request((ADIOI_Req_node *) (*request));
     *request = ADIO_REQUEST_NULL;
     *error_code = MPI_SUCCESS;
-
-/* status to be filled */
 }
 
 void ADIOI_HFS_WriteComplete(ADIO_Request *request, ADIO_Status *status, int *error_code)  
