@@ -1,20 +1,20 @@
 /* 
- *   $Id: ad_nfs.h,v 1.1.1.1 1999/03/17 18:52:47 jsquyres Exp $    
+ *   $Id: ad_nfs.h,v 1.1.1.1 2000/09/06 20:01:56 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
  */
 
-#ifndef __AD_NFS_INCLUDE
-#define __AD_NFS_INCLUDE
+#ifndef AD_NFS_INCLUDE
+#define AD_NFS_INCLUDE
 
 #include <unistd.h>
 #include <sys/types.h>
 #include <fcntl.h>
 #include "adio.h"
 
-#ifndef __NO_AIO
-#ifdef __AIO_SUN
+#ifndef NO_AIO
+#ifdef AIO_SUN
 #include <sys/asynch.h>
 #else
 #include <aio.h>
@@ -24,7 +24,7 @@
 int ADIOI_NFS_aio(ADIO_File fd, void *buf, int len, ADIO_Offset offset,
                   int wr, void *handle);
 
-#ifdef __SX4
+#ifdef SX4
 #define lseek llseek
 #endif
 
