@@ -1,5 +1,5 @@
 /* 
- *   $Id: ad_pfs.h,v 1.1.1.1 1999/03/17 18:52:46 jsquyres Exp $    
+ *   $Id: ad_pfs.h,v 1.1.1.1 2000/09/06 20:01:56 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -8,8 +8,8 @@
 /* contains definitions, declarations, and macros specific to the
    implementation of ADIO on PFS */
 
-#ifndef __AD_PFS_INCLUDE
-#define __AD_PFS_INCLUDE
+#ifndef AD_PFS_INCLUDE
+#define AD_PFS_INCLUDE
 
 #include <unistd.h>
 #include <sys/types.h>
@@ -18,4 +18,8 @@
 #include <sys/uio.h>
 #include "adio.h"
 
+#ifdef tflops
+#define lseek eseek
+#endif
+
 #endif
