@@ -1,5 +1,5 @@
 /* 
- *   $Id: ad_sfs_done.c,v 1.1.1.1 1999/03/17 18:52:51 jsquyres Exp $    
+ *   $Id: ad_sfs_done.c,v 1.1.1.1 2000/09/06 20:01:56 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -10,6 +10,9 @@
 int ADIOI_SFS_ReadDone(ADIO_Request *request, ADIO_Status *status, int *error_code)  
 {
     if (*request != ADIO_REQUEST_NULL) {
+#ifdef HAVE_STATUS_SET_BYTES
+	MPIR_Status_set_bytes(status, (*request)->datatype, (*request)->nbytes);
+#endif
 	(*request)->fd->async_count--;
 	ADIOI_Free_request((ADIOI_Req_node *) (*request));
 	*request = ADIO_REQUEST_NULL;
@@ -17,9 +20,6 @@ int ADIOI_SFS_ReadDone(ADIO_Request *request, ADIO_Status *status, int *error_co
 
     *error_code = MPI_SUCCESS;
     return 1;
-
-/* status to be filled */
-
 }
 
 
