@@ -1,12 +1,12 @@
 /* 
- *   $Id: ad_xfs.h,v 1.1.1.1 1999/03/17 18:52:51 jsquyres Exp $    
+ *   $Id: ad_xfs.h,v 1.1.1.1 2000/09/06 20:01:55 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
  */
 
-#ifndef __AD_XFS_INCLUDE
-#define __AD_XFS_INCLUDE
+#ifndef AD_XFS_INCLUDE
+#define AD_XFS_INCLUDE
 
 #include <unistd.h>
 #include <sys/types.h>
@@ -17,7 +17,7 @@
 int ADIOI_XFS_aio(ADIO_File fd, void *buf, int len, ADIO_Offset offset,
 		  int wr, void *handle);
 
-#ifdef __HAS_PREAD64
+#if (defined(HAVE_PREAD64) && (_ABIO32 == 1))
 #  define pread pread64
 #  define pwrite pwrite64
 #endif
