@@ -1,5 +1,5 @@
 /* 
- *   $Id: flatten.c,v 1.2 1999/06/12 17:14:19 kmeyer1 Exp $    
+ *   $Id: flatten.c,v 1.1.1.1 2000/09/06 20:01:55 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -7,7 +7,7 @@
 
 #include "adio.h"
 #include "adio_extern.h"
-#ifdef __MPISGI
+#ifdef MPISGI
 #include "mpisgi2.h"
 #endif
 
@@ -45,7 +45,7 @@ void ADIOI_Flatten_datatype(MPI_Datatype datatype)
     flat->indices = NULL;
 
     flat->count = ADIOI_Count_contiguous_blocks(datatype, &curr_index);
-/*    printf("%d\n", flat->count);*/
+/*    FPRINTF(stderr, "%d\n", flat->count);*/
 
     if (flat->count) {
 	flat->blocklens = (int *) ADIOI_Malloc(flat->count * sizeof(int));
@@ -58,14 +58,14 @@ void ADIOI_Flatten_datatype(MPI_Datatype datatype)
     ADIOI_Flatten(datatype, flat, 0, &curr_index);
 
 /* debug */
-    /*printf("blens: ");
+    /*FPRINTF(stderr, "blens: ");
     for (i=0; i<flat->count; i++) 
-	printf("%d ", flat->blocklens[i]);
-    printf("\n\n");
-    printf("indices: ");
+	FPRINTF(stderr, "%d ", flat->blocklens[i]);
+    FPRINTF(stderr, "\n\n");
+    FPRINTF(stderr, "indices: ");
     for (i=0; i<flat->count; i++) 
-	printf("%ld ", flat->indices[i]);
-    printf("\n\n");*/
+	FPRINTF(stderr, "%ld ", flat->indices[i]);
+    FPRINTF(stderr, "\n\n");*/
 
 }
 
@@ -390,11 +390,11 @@ void ADIOI_Flatten(MPI_Datatype datatype, ADIOI_Flatlist_node *flat,
  	break;
 
     default:
-	printf("Error: Unsupported datatype passed to ADIOI_Flatten\n");
+	FPRINTF(stderr, "Error: Unsupported datatype passed to ADIOI_Flatten\n");
 	MPI_Abort(MPI_COMM_WORLD, 1);
     }
 
-#ifndef __MPISGI
+#ifndef MPISGI
 /* There is a bug in SGI's impl. of MPI_Type_get_contents. It doesn't
    return new datatypes. Therefore no need to free. */
     for (i=0; i<ntypes; i++) {
@@ -422,7 +422,7 @@ int ADIOI_Count_contiguous_blocks(MPI_Datatype datatype, int *curr_index)
     int *ints;
     MPI_Aint *adds;
     MPI_Datatype *types;
-    
+
     MPI_Type_get_envelope(datatype, &nints, &nadds, &ntypes, &combiner);
     ints = (int *) ADIOI_Malloc((nints+1)*sizeof(int));
     adds = (MPI_Aint *) ADIOI_Malloc((nadds+1)*sizeof(MPI_Aint));
@@ -548,23 +548,11 @@ int ADIOI_Count_contiguous_blocks(MPI_Datatype datatype, int *curr_index)
 	}
 	break;
     default:
-#if defined (__MPILAM) 
-      printf("Error: Unsupported datatype passed to ADIOI_Count_contiguous_blocks\n");
-      if (combiner == MPI_COMBINER_DARRAY) {
-	printf("Error: LAM MPI-2 datatype darray is not supported in this version.\n");
+	FPRINTF(stderr, "Error: Unsupported datatype passed to ADIOI_Count_contiguous_blocks\n");
 	MPI_Abort(MPI_COMM_WORLD, 1);
-      }
-      if (combiner == MPI_COMBINER_SUBARRAY) {
-	printf("Error: LAM MPI-2 datatype subarray is not supported in this version.\n");
-	MPI_Abort(MPI_COMM_WORLD, 1);
-      }
-#else
-    	printf("Error: Unsupported datatype passed to ADIOI_Count_contiguous_blocks\n");
-	MPI_Abort(MPI_COMM_WORLD, 1);
-#endif
     }
 
-#ifndef __MPISGI
+#ifndef MPISGI
 /* There is a bug in SGI's impl. of MPI_Type_get_contents. It doesn't
    return new datatypes. Therefore no need to free. */
     for (i=0; i<ntypes; i++) {
