@@ -1,27 +1,31 @@
 /* 
- *   $Id: adioi_fs_proto.h,v 1.1.1.1 1999/03/17 18:52:46 jsquyres Exp $    
+ *   $Id: adioi_fs_proto.h,v 1.2 2001/01/25 05:33:33 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
  */
 
 
-#ifndef __ADIO_PROTO
-#define __ADIO_PROTO
+#ifndef ADIO_PROTO
+#define ADIO_PROTO
 
-#ifdef __NFS
+#ifdef NFS
 void ADIOI_NFS_Open(ADIO_File fd, int *error_code);
 void ADIOI_NFS_Close(ADIO_File fd, int *error_code);
-void ADIOI_NFS_ReadContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_NFS_ReadContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                      ADIO_Offset offset, ADIO_Status *status, int
 		     *error_code);
-void ADIOI_NFS_WriteContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_NFS_WriteContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Status *status, int
 		      *error_code);   
-void ADIOI_NFS_IwriteContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_NFS_IwriteContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Request *request, int
 		      *error_code);   
-void ADIOI_NFS_IreadContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_NFS_IreadContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Request *request, int
 		      *error_code);   
 int ADIOI_NFS_ReadDone(ADIO_Request *request, ADIO_Status *status, int
@@ -63,21 +67,28 @@ void ADIOI_NFS_Resize(ADIO_File fd, ADIO_Offset size, int *error_code);
 ADIO_Offset ADIOI_NFS_SeekIndividual(ADIO_File fd, ADIO_Offset offset, 
                        int whence, int *error_code);
 void ADIOI_NFS_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code);
+void ADIOI_NFS_Get_shared_fp(ADIO_File fd, int size, ADIO_Offset *shared_fp, 
+			 int *error_code);
+void ADIOI_NFS_Set_shared_fp(ADIO_File fd, ADIO_Offset offset, int *error_code);
 #endif
 
-#ifdef __PFS
+#ifdef PFS
 void ADIOI_PFS_Open(ADIO_File fd, int *error_code);
 void ADIOI_PFS_Close(ADIO_File fd, int *error_code);
-void ADIOI_PFS_ReadContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_PFS_ReadContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                      ADIO_Offset offset, ADIO_Status *status, int
 		     *error_code);
-void ADIOI_PFS_WriteContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_PFS_WriteContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Status *status, int
 		      *error_code);   
-void ADIOI_PFS_IwriteContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_PFS_IwriteContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Request *request, int
 		      *error_code);   
-void ADIOI_PFS_IreadContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_PFS_IreadContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Request *request, int
 		      *error_code);   
 int ADIOI_PFS_ReadDone(ADIO_Request *request, ADIO_Status *status, int
@@ -121,19 +132,23 @@ ADIO_Offset ADIOI_PFS_SeekIndividual(ADIO_File fd, ADIO_Offset offset,
 void ADIOI_PFS_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code);
 #endif
 
-#ifdef __PIOFS
+#ifdef PIOFS
 void ADIOI_PIOFS_Open(ADIO_File fd, int *error_code);
 void ADIOI_PIOFS_Close(ADIO_File fd, int *error_code);
-void ADIOI_PIOFS_ReadContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_PIOFS_ReadContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                      ADIO_Offset offset, ADIO_Status *status, int
 		     *error_code);
-void ADIOI_PIOFS_WriteContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_PIOFS_WriteContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Status *status, int
 		      *error_code);   
-void ADIOI_PIOFS_IwriteContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_PIOFS_IwriteContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Request *request, int
 		      *error_code);   
-void ADIOI_PIOFS_IreadContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_PIOFS_IreadContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Request *request, int
 		      *error_code);   
 int ADIOI_PIOFS_ReadDone(ADIO_Request *request, ADIO_Status *status, int
@@ -177,19 +192,23 @@ ADIO_Offset ADIOI_PIOFS_SeekIndividual(ADIO_File fd, ADIO_Offset offset,
 void ADIOI_PIOFS_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code);
 #endif
 
-#ifdef __UFS
+#ifdef UFS
 void ADIOI_UFS_Open(ADIO_File fd, int *error_code);
 void ADIOI_UFS_Close(ADIO_File fd, int *error_code);
-void ADIOI_UFS_ReadContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_UFS_ReadContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                      ADIO_Offset offset, ADIO_Status *status, int
 		     *error_code);
-void ADIOI_UFS_WriteContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_UFS_WriteContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Status *status, int
 		      *error_code);   
-void ADIOI_UFS_IwriteContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_UFS_IwriteContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Request *request, int
 		      *error_code);   
-void ADIOI_UFS_IreadContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_UFS_IreadContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Request *request, int
 		      *error_code);   
 int ADIOI_UFS_ReadDone(ADIO_Request *request, ADIO_Status *status, int
@@ -233,19 +252,23 @@ ADIO_Offset ADIOI_UFS_SeekIndividual(ADIO_File fd, ADIO_Offset offset,
 void ADIOI_UFS_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code);
 #endif
 
-#ifdef __HFS
+#ifdef HFS
 void ADIOI_HFS_Open(ADIO_File fd, int *error_code);
 void ADIOI_HFS_Close(ADIO_File fd, int *error_code);
-void ADIOI_HFS_ReadContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_HFS_ReadContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                      ADIO_Offset offset, ADIO_Status *status, int
 		     *error_code);
-void ADIOI_HFS_WriteContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_HFS_WriteContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Status *status, int
 		      *error_code);   
-void ADIOI_HFS_IwriteContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_HFS_IwriteContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Request *request, int
 		      *error_code);   
-void ADIOI_HFS_IreadContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_HFS_IreadContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Request *request, int
 		      *error_code);   
 int ADIOI_HFS_ReadDone(ADIO_Request *request, ADIO_Status *status, int
@@ -289,19 +312,23 @@ ADIO_Offset ADIOI_HFS_SeekIndividual(ADIO_File fd, ADIO_Offset offset,
 void ADIOI_HFS_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code);
 #endif
 
-#ifdef __XFS
+#ifdef XFS
 void ADIOI_XFS_Open(ADIO_File fd, int *error_code);
 void ADIOI_XFS_Close(ADIO_File fd, int *error_code);
-void ADIOI_XFS_ReadContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_XFS_ReadContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                      ADIO_Offset offset, ADIO_Status *status, int
 		     *error_code);
-void ADIOI_XFS_WriteContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_XFS_WriteContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Status *status, int
 		      *error_code);   
-void ADIOI_XFS_IwriteContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_XFS_IwriteContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Request *request, int
 		      *error_code);   
-void ADIOI_XFS_IreadContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_XFS_IreadContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Request *request, int
 		      *error_code);   
 int ADIOI_XFS_ReadDone(ADIO_Request *request, ADIO_Status *status, int
@@ -345,19 +372,23 @@ ADIO_Offset ADIOI_XFS_SeekIndividual(ADIO_File fd, ADIO_Offset offset,
 void ADIOI_XFS_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code);
 #endif
 
-#ifdef __SFS
+#ifdef SFS
 void ADIOI_SFS_Open(ADIO_File fd, int *error_code);
 void ADIOI_SFS_Close(ADIO_File fd, int *error_code);
-void ADIOI_SFS_ReadContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_SFS_ReadContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                      ADIO_Offset offset, ADIO_Status *status, int
 		     *error_code);
-void ADIOI_SFS_WriteContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_SFS_WriteContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Status *status, int
 		      *error_code);   
-void ADIOI_SFS_IwriteContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_SFS_IwriteContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Request *request, int
 		      *error_code);   
-void ADIOI_SFS_IreadContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_SFS_IreadContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
                       ADIO_Offset offset, ADIO_Request *request, int
 		      *error_code);   
 int ADIOI_SFS_ReadDone(ADIO_Request *request, ADIO_Status *status, int
@@ -401,4 +432,64 @@ ADIO_Offset ADIOI_SFS_SeekIndividual(ADIO_File fd, ADIO_Offset offset,
 void ADIOI_SFS_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code);
 #endif
 
+#ifdef ROMIO_HAVE_PVFS
+void ADIOI_PVFS_Open(ADIO_File fd, int *error_code);
+void ADIOI_PVFS_Close(ADIO_File fd, int *error_code);
+void ADIOI_PVFS_ReadContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
+                     ADIO_Offset offset, ADIO_Status *status, int
+		     *error_code);
+void ADIOI_PVFS_WriteContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
+                      ADIO_Offset offset, ADIO_Status *status, int
+		      *error_code);   
+void ADIOI_PVFS_IwriteContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
+                      ADIO_Offset offset, ADIO_Request *request, int
+		      *error_code);   
+void ADIOI_PVFS_IreadContig(ADIO_File fd, void *buf, int count, 
+                      MPI_Datatype datatype, int file_ptr_type,
+                      ADIO_Offset offset, ADIO_Request *request, int
+		      *error_code);   
+int ADIOI_PVFS_ReadDone(ADIO_Request *request, ADIO_Status *status, int
+		       *error_code);
+int ADIOI_PVFS_WriteDone(ADIO_Request *request, ADIO_Status *status, int
+		       *error_code);
+void ADIOI_PVFS_ReadComplete(ADIO_Request *request, ADIO_Status *status, int
+		       *error_code); 
+void ADIOI_PVFS_WriteComplete(ADIO_Request *request, ADIO_Status *status,
+			int *error_code); 
+void ADIOI_PVFS_Fcntl(ADIO_File fd, int flag, ADIO_Fcntl_t *fcntl_struct, int
+		*error_code); 
+void ADIOI_PVFS_WriteStrided(ADIO_File fd, void *buf, int count,
+		       MPI_Datatype datatype, int file_ptr_type,
+		       ADIO_Offset offset, ADIO_Status *status, int
+		       *error_code);
+void ADIOI_PVFS_ReadStrided(ADIO_File fd, void *buf, int count,
+		       MPI_Datatype datatype, int file_ptr_type,
+		       ADIO_Offset offset, ADIO_Status *status, int
+		       *error_code);
+void ADIOI_PVFS_WriteStridedColl(ADIO_File fd, void *buf, int count,
+		       MPI_Datatype datatype, int file_ptr_type,
+		       ADIO_Offset offset, ADIO_Status *status, int
+		       *error_code);
+void ADIOI_PVFS_ReadStridedColl(ADIO_File fd, void *buf, int count,
+		       MPI_Datatype datatype, int file_ptr_type,
+		       ADIO_Offset offset, ADIO_Status *status, int
+		       *error_code);
+void ADIOI_PVFS_IreadStrided(ADIO_File fd, void *buf, int count,
+		       MPI_Datatype datatype, int file_ptr_type,
+		       ADIO_Offset offset, ADIO_Request *request, int
+		       *error_code);
+void ADIOI_PVFS_IwriteStrided(ADIO_File fd, void *buf, int count,
+		       MPI_Datatype datatype, int file_ptr_type,
+		       ADIO_Offset offset, ADIO_Request *request, int
+		       *error_code);
+void ADIOI_PVFS_Flush(ADIO_File fd, int *error_code);
+void ADIOI_PVFS_Resize(ADIO_File fd, ADIO_Offset size, int *error_code);
+ADIO_Offset ADIOI_PVFS_SeekIndividual(ADIO_File fd, ADIO_Offset offset, 
+                       int whence, int *error_code);
+void ADIOI_PVFS_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code);
+#endif
+
 #endif
