@@ -1,5 +1,5 @@
 /* 
- *   $Id: get_size.c,v 1.1.1.1 1999/03/17 18:52:54 jsquyres Exp $    
+ *   $Id: get_size.c,v 1.1.1.1 2000/09/06 20:01:53 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -7,6 +7,22 @@
 
 #include "mpioimpl.h"
 
+#ifdef HAVE_WEAK_SYMBOLS
+
+#if defined(HAVE_PRAGMA_WEAK)
+#pragma weak MPI_File_get_size = PMPI_File_get_size
+#elif defined(HAVE_PRAGMA_HP_SEC_DEF)
+#pragma _HP_SECONDARY_DEF PMPI_File_get_size MPI_File_get_size
+#elif defined(HAVE_PRAGMA_CRI_DUP)
+#pragma _CRI duplicate MPI_File_get_size as PMPI_File_get_size
+/* end of weak pragmas */
+#endif
+
+/* Include mapping from MPI->PMPI */
+#define MPIO_BUILD_PROFILING
+#include "mpioprof.h"
+#endif
+
 /*@
     MPI_File_get_size - Returns the file size
 
@@ -22,6 +38,9 @@ int MPI_File_get_size(MPI_File fh, MPI_Offset *size)
 {
     ADIO_Fcntl_t *fcntl_struct;
     int error_code;
+#ifndef PRINT_ERR_MSG
+    static char myname[] = "MPI_FILE_GET_SIZE";
+#endif
 #ifdef MPI_hpux
     int fl_xmpi;
 
@@ -29,10 +48,14 @@ int MPI_File_get_size(MPI_File fh, MPI_Offset *size)
 		  MPI_DATATYPE_NULL, -1);
 #endif /* MPI_hpux */
 
+#ifdef PRINT_ERR_MSG
     if ((fh <= (MPI_File) 0) || (fh->cookie != ADIOI_FILE_COOKIE)) {
-	printf("MPI_File_get_size: Invalid file handle\n");
+	FPRINTF(stderr, "MPI_File_get_size: Invalid file handle\n");
 	MPI_Abort(MPI_COMM_WORLD, 1);
     }
+#else
+    ADIOI_TEST_FILE_HANDLE(fh, myname);
+#endif
 
     fcntl_struct = (ADIO_Fcntl_t *) ADIOI_Malloc(sizeof(ADIO_Fcntl_t));
     ADIO_Fcntl(fh, ADIO_FCNTL_GET_FSIZE, fcntl_struct, &error_code);
