@@ -1,11 +1,27 @@
 /* 
- *   $Id: ioreq_f2c.c,v 1.1.1.1 1999/03/17 18:52:54 jsquyres Exp $    
+ *   $Id: ioreq_f2c.c,v 1.1.1.1 2000/09/06 20:01:53 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
  */
 
 #include "mpioimpl.h"
+
+#ifdef HAVE_WEAK_SYMBOLS
+
+#if defined(HAVE_PRAGMA_WEAK)
+#pragma weak MPIO_Request_f2c = PMPIO_Request_f2c
+#elif defined(HAVE_PRAGMA_HP_SEC_DEF)
+#pragma _HP_SECONDARY_DEF PMPIO_Request_f2c MPIO_Request_f2c
+#elif defined(HAVE_PRAGMA_CRI_DUP)
+#pragma _CRI duplicate MPIO_Request_f2c as PMPIO_Request_f2c
+/* end of weak pragmas */
+#endif
+
+/* Include mapping from MPI->PMPI */
+#define MPIO_BUILD_PROFILING
+#include "mpioprof.h"
+#endif
 #include "adio_extern.h"
 
 /*@
@@ -13,7 +29,7 @@
                        a C I/O-request handle
 
 Input Parameters:
-. fh - Fortran I/O-request handle (integer)
+. request - Fortran I/O-request handle (integer)
 
 Return Value:
   C I/O-request handle (handle)
@@ -21,12 +37,12 @@ Return Value:
 MPIO_Request MPIO_Request_f2c(MPI_Fint request)
 {
 
-#ifndef __INT_LT_POINTER
+#ifndef INT_LT_POINTER
     return (MPIO_Request) request;
 #else
     if (!request) return MPIO_REQUEST_NULL;
     if ((request < 0) || (request > ADIOI_Reqtable_ptr)) {
-	printf("MPIO_Request_f2c: Invalid request\n");
+	FPRINTF(stderr, "MPIO_Request_f2c: Invalid request\n");
 	MPI_Abort(MPI_COMM_WORLD, 1);
     }
     return ADIOI_Reqtable[request];
