@@ -1,5 +1,5 @@
 /* 
- *   $Id: mpioimpl.h,v 1.1.1.1 1999/03/17 18:52:55 jsquyres Exp $    
+ *   $Id: mpioimpl.h,v 1.1.1.1 2000/09/06 20:01:53 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -9,8 +9,8 @@
 /* header file for MPI-IO implementation. not intended to be
    user-visible */ 
 
-#ifndef __MPIOIMPL_INCLUDE
-#define __MPIOIMPL_INCLUDE
+#ifndef MPIOIMPL_INCLUDE
+#define MPIOIMPL_INCLUDE
 
 #include "mpio.h"
 #include "adio.h"
