@@ -1,5 +1,5 @@
 /* 
- *   $Id: info_delete.c,v 1.1.1.1 1999/03/17 18:53:03 jsquyres Exp $    
+ *   $Id: info_delete.c,v 1.1.1.1 2000/09/06 20:01:52 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -7,6 +7,22 @@
 
 #include "mpioimpl.h"
 
+#ifdef HAVE_WEAK_SYMBOLS
+
+#if defined(HAVE_PRAGMA_WEAK)
+#pragma weak MPI_Info_delete = PMPI_Info_delete
+#elif defined(HAVE_PRAGMA_HP_SEC_DEF)
+#pragma _HP_SECONDARY_DEF PMPI_Info_delete MPI_Info_delete
+#elif defined(HAVE_PRAGMA_CRI_DUP)
+#pragma _CRI duplicate MPI_Info_delete as PMPI_Info_delete
+/* end of weak pragmas */
+#endif
+
+/* Include mapping from MPI->PMPI */
+#define MPIO_BUILD_PROFILING
+#include "mpioprof.h"
+#endif
+
 /*@
     MPI_Info_delete - Deletes a (key,value) pair from info
 
@@ -22,22 +38,22 @@ int MPI_Info_delete(MPI_Info info, char *key)
     int done;
 
     if ((info <= (MPI_Info) 0) || (info->cookie != MPIR_INFO_COOKIE)) {
-        printf("MPI_Info_delete: Invalid info object\n");
+        FPRINTF(stderr, "MPI_Info_delete: Invalid info object\n");
         MPI_Abort(MPI_COMM_WORLD, 1);
     }
 
     if (key <= (char *) 0) {
-	printf("MPI_Info_delete: key is an invalid address\n");
+	FPRINTF(stderr, "MPI_Info_delete: key is an invalid address\n");
         MPI_Abort(MPI_COMM_WORLD, 1);
     }
 
     if (strlen(key) > MPI_MAX_INFO_KEY) {
-	printf("MPI_Info_delete: key is longer than MPI_MAX_INFO_KEY\n");
+	FPRINTF(stderr, "MPI_Info_delete: key is longer than MPI_MAX_INFO_KEY\n");
         MPI_Abort(MPI_COMM_WORLD, 1);
     }
 
     if (!strlen(key)) {
-	printf("MPI_Info_delete: key is a null string\n");
+	FPRINTF(stderr, "MPI_Info_delete: key is a null string\n");
         MPI_Abort(MPI_COMM_WORLD, 1);
     }
 
@@ -59,7 +75,7 @@ int MPI_Info_delete(MPI_Info info, char *key)
     }
 
     if (!done) {
-	printf("MPI_Info_delete: key not defined in info\n");
+	FPRINTF(stderr, "MPI_Info_delete: key not defined in info\n");
         MPI_Abort(MPI_COMM_WORLD, 1);	
     }
 
