@@ -1,5 +1,5 @@
 /* 
- *   $Id: info_free.c,v 1.1.1.1 1999/03/17 18:53:04 jsquyres Exp $    
+ *   $Id: info_free.c,v 1.1.1.1 2000/09/06 20:01:52 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -7,6 +7,22 @@
 
 #include "mpioimpl.h"
 
+#ifdef HAVE_WEAK_SYMBOLS
+
+#if defined(HAVE_PRAGMA_WEAK)
+#pragma weak MPI_Info_free = PMPI_Info_free
+#elif defined(HAVE_PRAGMA_HP_SEC_DEF)
+#pragma _HP_SECONDARY_DEF PMPI_Info_free MPI_Info_free
+#elif defined(HAVE_PRAGMA_CRI_DUP)
+#pragma _CRI duplicate MPI_Info_free as PMPI_Info_free
+/* end of weak pragmas */
+#endif
+
+/* Include mapping from MPI->PMPI */
+#define MPIO_BUILD_PROFILING
+#include "mpioprof.h"
+#endif
+
 /*@
     MPI_Info_free - Frees an info object
 
@@ -20,7 +36,7 @@ int MPI_Info_free(MPI_Info *info)
     MPI_Info curr, next;
 
     if ((*info <= (MPI_Info) 0) || ((*info)->cookie != MPIR_INFO_COOKIE)) {
-        printf("MPI_Info_free: Invalid info object\n");
+        FPRINTF(stderr, "MPI_Info_free: Invalid info object\n");
         MPI_Abort(MPI_COMM_WORLD, 1);
     }
 
