@@ -1,6 +1,6 @@
 /*
  * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
  *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
  * 
  * This file is part of the Notre Dame LAM implementation of MPI.
@@ -10,18 +10,21 @@
  * LICENSE.  If not, contact Office of Research, University of Notre
  * Dame, Notre Dame, IN 46556.
  * 
- * Permission to modify the code and to distribute modified code is
- * granted, provided the text of this NOTICE is retained, a notice that
- * the code was modified is included with the above COPYRIGHT NOTICE and
- * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
- * file is distributed with the modified code.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted subject to the conditions specified in the
+ * LICENSE file.
  * 
- * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
- * By way of example, but not limitation, Licensor MAKES NO
- * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
- * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
- * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
+ * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+ * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
+ * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
+ * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  * 
  * Additional copyrights may follow.
  * 
@@ -29,7 +32,7 @@
  *	Copyright 1996 The Ohio State University
  *	RBD/GDB
  *
- *	$Id: lamnet.c,v 6.5 2000/03/06 21:12:31 jsquyres Exp $
+ *	$Id: lamnet.c,v 6.5.2.1 2001/10/07 20:18:26 jsquyres Exp $
  * 
  *	Function:	- LAM network functions
  */
@@ -77,7 +80,6 @@ static int		getifaddr();
 /*
  * local variables
  */
-static char		origname[MAXHOSTNAMELEN + 1];
 static unsigned long	ifbuf[256];
 
 /*
@@ -90,34 +92,15 @@ static unsigned long	ifbuf[256];
  *			- bad host index (out)
  */
 int
-lamnet_findhosts(lamnet, nlamnet, badhost)
-
-struct lamnode		*lamnet;
-int			nlamnet;
-int			*badhost;
-
+lamnet_findhosts(struct lamnode *lamnet, int nlamnet, int *badhost)
 {
 	int		i;
 
 	if (badhost) *badhost = -1;
-/*
- * Get the hostname of the machine the tool is running on.
- */
-	if (gethostname(origname, MAXHOSTNAMELEN)) return(LAMERROR);
 /*
  * Find INET addresses for each node.
  */
 	for (i = 0; i < nlamnet; ++i) {
-/*
- * Change "localhost" to the real host name.
- */
-		if (! strcmp(lamnet[i].lnd_hname, "localhost")) {
-			free(lamnet[i].lnd_hname);
-			lamnet[i].lnd_hname = malloc((unsigned)
-					strlen(origname) + 1);
-			if (lamnet[i].lnd_hname == 0) return(LAMERROR);
-			strcpy(lamnet[i].lnd_hname, origname);
-		}
 /*
  * Get the host network address.
  */
@@ -147,11 +130,7 @@ int			*badhost;
  *	Returns:	- index of origin or LAMERROR
  */
 int
-lamnet_findorig(lamnet, nlamnet)
-
-struct lamnode		*lamnet;
-int			nlamnet;
-
+lamnet_findorig(struct lamnode *lamnet, int nlamnet)
 {
 	int		i, j;
 	int		nifaddr;	/* # of interface addresses */
@@ -164,9 +143,7 @@ int			nlamnet;
  * our local host interface addresses.
  */
 	for (i = 0; i < nlamnet; ++i) {
-
 		for (j = 0; j < nifaddr; ++j) {
-
 			if (ifaddr[j] == lamnet[i].lnd_addr.sin_addr.s_addr) {
 				return(i);
 			}
@@ -194,12 +171,7 @@ int			nlamnet;
  *	Returns:	- TRUE if duplicates, else FALSE
  */
 int
-lamnet_dups(lamnet, nlamnet, pdup)
-
-struct lamnode		*lamnet;
-int			nlamnet;
-int			*pdup;
-
+lamnet_dups(struct lamnode *lamnet, int nlamnet, int *pdup)
 {
 	int		i, j;
 /*
@@ -236,11 +208,7 @@ int			*pdup;
  *	Returns:	- number of addresses or LAMERROR
  */
 static int
-getifaddr(ifaddr, nifaddr)
-
-uint4			*ifaddr;
-int			nifaddr;
-
+getifaddr(uint4 *ifaddr, int nifaddr)
 {
 	int		sock;
 	int		length;
