@@ -1,6 +1,6 @@
 /*
  * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
  *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
  * 
  * This file is part of the Notre Dame LAM implementation of MPI.
@@ -10,18 +10,21 @@
  * LICENSE.  If not, contact Office of Research, University of Notre
  * Dame, Notre Dame, IN 46556.
  * 
- * Permission to modify the code and to distribute modified code is
- * granted, provided the text of this NOTICE is retained, a notice that
- * the code was modified is included with the above COPYRIGHT NOTICE and
- * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
- * file is distributed with the modified code.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted subject to the conditions specified in the
+ * LICENSE file.
  * 
- * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
- * By way of example, but not limitation, Licensor MAKES NO
- * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
- * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
- * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
+ * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+ * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
+ * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
+ * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  * 
  * Additional copyrights may follow.
  * 
@@ -29,7 +32,7 @@
  *	Copyright 1997 The Ohio State University
  *	NJN
  *
- *	$Id: registry.c,v 1.1 1999/07/28 00:31:53 jsquyres Exp $
+ *	$Id: registry.c,v 1.1.2.1 2001/11/12 21:46:40 brbarret Exp $
  *
  *	Function:	- object registry
  *			- mechanism for registering semi-persistent
@@ -58,7 +61,9 @@
 #include <sys/stat.h>
 #include <sys/ipc.h>
 #include <sys/shm.h>
+#if LAM_HAVE_SYSV_SEMAPHORES
 #include <sys/sem.h>
+#endif
 #include <unistd.h>
 
 #include <terror.h>
@@ -109,6 +114,8 @@ static char		*reg_tmpname = 0;	/* temporary filename */
 static char		*reg_lockname = 0;	/* registry lock filename */
 static int		lockfd;			/* lock file descriptor */
 
+#if LAM_HAVE_SYSV_SEMAPHORES
+
 #if LAM_HAVE_UNION_SEMUN
 static	union semun	semctl_arg;
 #else
@@ -119,6 +126,7 @@ static union {
 } semctl_arg;
 #endif
 
+#endif /* #if LAM_HAVE_SYSV_SEMAPHORES */
 
 /*
  *	lam_register_objects
@@ -381,10 +389,12 @@ lam_cleanup_objects()
 	    sysvid = atoi(obj);
 	    shmctl(sysvid, IPC_RMID, (struct shmid_ds *) 0);
 	    break;
+#if LAM_HAVE_SYSV_SEMAPHORES
 	case 's':
 	    sysvid = atoi(obj);
 	    semctl(sysvid, 0, IPC_RMID, semctl_arg);
 	    break;
+#endif
 	case 'f':
 	    unlink(obj);
 	    break;
