@@ -1,6 +1,6 @@
 /*
  * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
  *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
  * 
  * This file is part of the Notre Dame LAM implementation of MPI.
@@ -10,23 +10,26 @@
  * LICENSE.  If not, contact Office of Research, University of Notre
  * Dame, Notre Dame, IN 46556.
  * 
- * Permission to modify the code and to distribute modified code is
- * granted, provided the text of this NOTICE is retained, a notice that
- * the code was modified is included with the above COPYRIGHT NOTICE and
- * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
- * file is distributed with the modified code.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted subject to the conditions specified in the
+ * LICENSE file.
  * 
- * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
- * By way of example, but not limitation, Licensor MAKES NO
- * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
- * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
- * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
+ * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+ * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
+ * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
+ * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  * 
  * Additional copyrights may follow.
  * 
  *
- *	$Id: MPISYSF.h,v 6.7 2001/03/20 06:14:31 jsquyres Exp $
+ *	$Id: MPISYSF.h,v 6.7.2.2 2001/11/09 20:57:50 brbarret Exp $
  *
  *	Function:	- F77 wrappers for MPI library
  */
@@ -1435,6 +1438,22 @@
 #define mpi_type_dup_fn_		MPI_F_TYPE_DUP_FN
 #define mpi_win_dup_fn_			MPI_F_WIN_DUP_FN
 
+/*
+ * DO NOT DELETE THESE UNDEF's.  They really should be here...
+ * 
+ * There is a name clash between the C constant MPI_NULL_COPY_FN (and
+ * all the other undef'ed functions below) defined in mpi.h and the
+ * Fortran version when the Fortran naming convention is uppercase.
+ *
+ * Since we really need to have a Fortran version of MPI_NULL_COPY_FN
+ * (and all the other undef'ed functions below), we undef the C
+ * versions.  This then causes some problems for the Fortran bindings,
+ * who actually need access to the C constants in mpi.h.  In this
+ * case, the Fortran bindings should use LAM_MPI_NULL_COPY_FN (and all
+ * the other undef'ed functions below, prepened with LAM_).  The
+ * correct #defines are in mpi.h to make this work out ok.
+ */
+
 #undef MPI_NULL_COPY_FN
 #undef MPI_NULL_DELETE_FN
 #undef MPI_COMM_NULL_COPY_FN
@@ -1474,8 +1493,7 @@
 #elif LAM_FORTRANUNDERSCORE
 
 /*
- * single underscore convention
- */
+ * single underscore convention */
 
 #ifdef LAM_PROFILELIB
 
