@@ -1,6 +1,6 @@
 /*
  * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
  *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
  * 
  * This file is part of the Notre Dame LAM implementation of MPI.
@@ -10,23 +10,26 @@
  * LICENSE.  If not, contact Office of Research, University of Notre
  * Dame, Notre Dame, IN 46556.
  * 
- * Permission to modify the code and to distribute modified code is
- * granted, provided the text of this NOTICE is retained, a notice that
- * the code was modified is included with the above COPYRIGHT NOTICE and
- * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
- * file is distributed with the modified code.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted subject to the conditions specified in the
+ * LICENSE file.
  * 
- * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
- * By way of example, but not limitation, Licensor MAKES NO
- * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
- * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
- * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
+ * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+ * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
+ * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
+ * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  * 
  * Additional copyrights may follow.
  * 
  *
- *	$Id: mpi.h,v 6.27 2001/01/23 01:24:47 jsquyres Exp $
+ *	$Id: mpi.h,v 6.27.2.1 2001/11/09 20:57:50 brbarret Exp $
  *
  *	Function:	- MPI header file
  */
@@ -124,6 +127,7 @@ typedef int	(MPI_Win_delete_attr_function)();
 #define MPI_CART		1		/* cartesian topology */
 #define MPI_GRAPH		2		/* graph topology */
 #define MPI_KEYVAL_INVALID	-1		/* invalid key value */
+
 #define MPI_TAG_UB		0		/* predefined attribute key */
 #define MPI_HOST		1		/* predefined attribute key */
 #define MPI_IO			2		/* predefined attribute key */
@@ -140,6 +144,12 @@ typedef int	(MPI_Win_delete_attr_function)();
 #define IMPI_HOST_SIZE          11              /* predefined attribute key */
 #define IMPI_HOST_COLOR         12              /* predefined attribute key */
 
+/*
+ * Predefined attributes, but LAM-specific
+ */
+#define LAM_UNIVERSE_NCPUS	13		/* predefined attribute key */
+#define LAM_UNIVERSE_NNODES	14		/* predefined attribute key */
+
 #define MPI_BOTTOM		((void *) 0)	/* base reference address */
 #define MPI_BSEND_OVERHEAD	40		/* size of bsend header + ptr */
 #define MPI_MAX_INFO_KEY	36		/* max info key length */
@@ -209,25 +219,48 @@ typedef int	(MPI_Win_delete_attr_function)();
 /*
  * NULL handles
  */
-#define MPI_GROUP_NULL		((MPI_Group) 0)
-#define MPI_COMM_NULL		((MPI_Comm) 0)
-#define MPI_DATATYPE_NULL	((MPI_Datatype) 0)
-#define MPI_REQUEST_NULL	((MPI_Request) 0)
-#define MPI_OP_NULL		((MPI_Op) 0)
-#define MPI_ERRHANDLER_NULL	((MPI_Errhandler) 0)
-#define MPI_NULL_COPY_FN	((MPI_Copy_function *) 0)
-#define MPI_NULL_DELETE_FN	((MPI_Delete_function *) 0)
-#define MPI_COMM_NULL_COPY_FN	((MPI_Comm_copy_attr_function *) 0)
-#define MPI_COMM_NULL_DELETE_FN	((MPI_Comm_delete_attr_function *) 0)
-#define MPI_TYPE_NULL_COPY_FN	((MPI_Type_copy_attr_function *) 0)
-#define MPI_TYPE_NULL_DELETE_FN	((MPI_Type_delete_attr_function *) 0)
-#define MPI_WIN_NULL_COPY_FN	((MPI_Win_copy_attr_function *) 0)
-#define MPI_WIN_NULL_DELETE_FN	((MPI_Win_delete_attr_function *) 0)
-#define MPI_INFO_NULL		((MPI_Info) 0)
-#define MPI_WIN_NULL		((MPI_Win) 0)
 
-#define MPI_STATUSES_IGNORE	((MPI_Status *) 0)
-#define MPI_STATUS_IGNORE	((MPI_Status *) 0)
+/* These need to be here - see note near #undefs in MPISYSF.h */
+#define LAM_MPI_C_GROUP_NULL	((MPI_Group) 0)
+#define LAM_MPI_C_COMM_NULL	((MPI_Comm) 0)
+#define LAM_MPI_C_DATATYPE_NULL	((MPI_Datatype) 0)
+#define LAM_MPI_C_REQUEST_NULL	((MPI_Request) 0)
+#define LAM_MPI_C_OP_NULL	((MPI_Op) 0)
+#define LAM_MPI_C_ERRHANDLER_NULL	((MPI_Errhandler) 0)
+#define LAM_MPI_C_NULL_COPY_FN	        ((MPI_Copy_function *) 0)
+#define LAM_MPI_C_NULL_DELETE_FN	((MPI_Delete_function *) 0)
+#define LAM_MPI_C_COMM_NULL_COPY_FN	((MPI_Comm_copy_attr_function *) 0)
+#define LAM_MPI_C_COMM_NULL_DELETE_FN	((MPI_Comm_delete_attr_function *) 0)
+#define LAM_MPI_C_TYPE_NULL_COPY_FN	((MPI_Type_copy_attr_function *) 0)
+#define LAM_MPI_C_TYPE_NULL_DELETE_FN	((MPI_Type_delete_attr_function *) 0)
+#define LAM_MPI_C_WIN_NULL_COPY_FN	((MPI_Win_copy_attr_function *) 0)
+#define LAM_MPI_C_WIN_NULL_DELETE_FN	((MPI_Win_delete_attr_function *) 0)
+#define LAM_MPI_C_INFO_NULL	((MPI_Info) 0)
+#define LAM_MPI_C_WIN_NULL	((MPI_Win) 0)
+
+#define LAM_MPI_C_STATUSES_IGNORE	((MPI_Status *) 0)
+#define LAM_MPI_C_STATUS_IGNORE	((MPI_Status *) 0)
+
+#define MPI_GROUP_NULL          LAM_MPI_C_GROUP_NULL
+#define MPI_COMM_NULL           LAM_MPI_C_COMM_NULL
+#define MPI_DATATYPE_NULL       LAM_MPI_C_DATATYPE_NULL
+#define MPI_REQUEST_NULL        LAM_MPI_C_REQUEST_NULL
+#define MPI_OP_NULL             LAM_MPI_C_OP_NULL
+#define MPI_ERRHANDLER_NULL     LAM_MPI_C_ERRHANDLER_NULL
+#define MPI_NULL_COPY_FN        LAM_MPI_C_NULL_COPY_FN
+#define MPI_NULL_DELETE_FN      LAM_MPI_C_NULL_DELETE_FN
+#define MPI_COMM_NULL_COPY_FN   LAM_MPI_C_COMM_NULL_COPY_FN
+#define MPI_COMM_NULL_DELETE_FN LAM_MPI_C_COMM_NULL_DELETE_FN
+#define MPI_TYPE_NULL_COPY_FN   LAM_MPI_C_TYPE_NULL_COPY_FN
+#define MPI_TYPE_NULL_DELETE_FN LAM_MPI_C_TYPE_NULL_DELETE_FN
+#define MPI_WIN_NULL_COPY_FN    LAM_MPI_C_WIN_NULL_COPY_FN
+#define MPI_WIN_NULL_DELETE_FN  LAM_MPI_C_WIN_NULL_DELETE_FN
+#define MPI_INFO_NULL           LAM_MPI_C_INFO_NULL
+#define MPI_WIN_NULL            LAM_MPI_C_WIN_NULL
+
+#define MPI_STATUSES_IGNORE     LAM_MPI_C_STATUSES_IGNORE
+#define MPI_STATUS_IGNORE       LAM_MPI_C_STATUS_IGNORE
+
 
 /*
  * Datatype combiners.
@@ -992,6 +1025,8 @@ extern int MPIL_Type_id __ARGS((MPI_Datatype, int *));
 extern int MPIL_Trace_on __ARGS((void));
 extern int MPIL_Trace_off __ARGS((void));
 extern int MPIL_Signal __ARGS((MPI_Comm, int, int));
+extern int MPIL_Request_set_name __ARGS((MPI_Request, char *));
+extern char *MPIL_Request_get_name __ARGS((MPI_Request));
 
 extern int PMPIL_Spawn __ARGS((MPI_Comm, char *, int, MPI_Comm *));
 extern int PMPIL_Comm_parent __ARGS((MPI_Comm *));
@@ -1002,6 +1037,8 @@ extern int PMPIL_Type_id __ARGS((MPI_Datatype, int *));
 extern int PMPIL_Trace_on __ARGS((void));
 extern int PMPIL_Trace_off __ARGS((void));
 extern int PMPIL_Signal __ARGS((MPI_Comm, int, int));
+extern int PMPIL_Request_set_name __ARGS((MPI_Request, char *));
+extern char *PMPIL_Request_get_name __ARGS((MPI_Request));
 
 extern int XMPI_Buoy __ARGS((const char* name));
 extern int XMPI_Coloron __ARGS((int red, int green, int blue));
