@@ -1,6 +1,6 @@
 /*
  * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
  *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
  * 
  * This file is part of the Notre Dame LAM implementation of MPI.
@@ -10,18 +10,21 @@
  * LICENSE.  If not, contact Office of Research, University of Notre
  * Dame, Notre Dame, IN 46556.
  * 
- * Permission to modify the code and to distribute modified code is
- * granted, provided the text of this NOTICE is retained, a notice that
- * the code was modified is included with the above COPYRIGHT NOTICE and
- * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
- * file is distributed with the modified code.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted subject to the conditions specified in the
+ * LICENSE file.
  * 
- * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
- * By way of example, but not limitation, Licensor MAKES NO
- * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
- * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
- * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
+ * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+ * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
+ * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
+ * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  * 
  * Additional copyrights may follow.
  * 
@@ -29,7 +32,7 @@
  *	Copyright 1997 The Ohio	State University
  *	NJN/RBD
  *
- *	$Id: testall_f.c,v 6.4 1999/09/02 01:34:32 prijks Exp $
+ *	$Id: testall_f.c,v 6.4.2.1 2001/11/09 20:57:51 brbarret Exp $
  *
  *	Function:	- MPI_Testall F77 wrapper
  */
@@ -71,7 +74,7 @@ int			*c, *rqs, *f, *sts, *ierr;
 	}
 
 	if ((void *) sts == lam_F_statuses_ignore) {
-		stats = MPI_STATUSES_IGNORE;
+		stats = LAM_MPI_C_STATUSES_IGNORE;
 	}
 	else if ((void *) sts == lam_F_status_ignore) {
 		lam_setfunc(BLKMPITESTALL);
@@ -87,7 +90,7 @@ int			*c, *rqs, *f, *sts, *ierr;
 
 	if ((*ierr == MPI_SUCCESS) && (*f != 0)) {
 		for (i = 0; i <	*c; ++i) {
-			if (reqs[i] == MPI_REQUEST_NULL) {
+			if (reqs[i] == LAM_MPI_C_REQUEST_NULL) {
 				lam_F_free_hdl(rqs[i]);
 				rqs[i] = -1;
 			}
