@@ -1,6 +1,6 @@
 /*
  * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
  *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
  * 
  * This file is part of the Notre Dame LAM implementation of MPI.
@@ -10,23 +10,26 @@
  * LICENSE.  If not, contact Office of Research, University of Notre
  * Dame, Notre Dame, IN 46556.
  * 
- * Permission to modify the code and to distribute modified code is
- * granted, provided the text of this NOTICE is retained, a notice that
- * the code was modified is included with the above COPYRIGHT NOTICE and
- * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
- * file is distributed with the modified code.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted subject to the conditions specified in the
+ * LICENSE file.
  * 
- * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
- * By way of example, but not limitation, Licensor MAKES NO
- * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
- * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
- * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
+ * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+ * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
+ * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
+ * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  * 
  * Additional copyrights may follow.
  * 
  *
- *	$Id: init.c,v 6.39 2001/03/20 06:16:06 jsquyres Exp $
+ *	$Id: init.c,v 6.39.2.5 2001/11/18 01:57:11 jsquyres Exp $
  *
  *	Function:	- initialize the MPI session
  *			- the kitchen-sink of MPI
@@ -59,15 +62,6 @@
 #endif
 
 
-/*
- * MPISYSF.h undefines the corresponding C constants defined in mpi.h.
- */
-#define MPI_C_NULL_COPY_FN		((MPI_Copy_function *) 0)
-#define MPI_C_NULL_DELETE_FN		((MPI_Delete_function *) 0)
-#define MPI_C_WIN_NULL_COPY_FN		((MPI_Win_copy_attr_function *) 0)
-#define MPI_C_WIN_NULL_DELETE_FN	((MPI_Win_delete_attr_function *) 0)
-
-
 /*
  * private variables
  */
@@ -115,6 +109,7 @@ extern double		mpi_statuses_ignore_[];
  */
 static int init_comm(void);
 static int init_env(void);
+static int init_fcomplex_types(void);
 static int init_rdtype(void);
 static int init_f77(void);
 static void init_dtype(void);
@@ -314,7 +309,7 @@ int MPI_Init(int *pargc, char ***pargv)
 
 	if (init_comm()) {
 		free((char *) mpi_procs);
-		return(lam_errfunc(MPI_COMM_NULL,
+		return(lam_errfunc(LAM_MPI_C_COMM_NULL,
 			BLKMPIINIT, lam_mkerr(MPI_ERR_OTHER, errno)));
 	}
 	
@@ -337,14 +332,15 @@ int MPI_Init(int *pargc, char ***pargv)
 
 	if (_kio.ki_rtf & RTF_MPISIGS) {
 		if (lam_mpi_set_sighandlers()) {
-			return(lam_errfunc(MPI_COMM_NULL,
+			return(lam_errfunc(LAM_MPI_C_COMM_NULL,
 				BLKMPIINIT, lam_mkerr(MPI_ERR_OTHER, errno)));
 		}
 	}
 
-	if (init_rdtype() || init_env() || lam_init_onesided() || init_f77()) {
-		return(lam_errfunc(MPI_COMM_NULL,
-			BLKMPIINIT, lam_mkerr(MPI_ERR_OTHER, errno)));
+	if (init_rdtype() || init_fcomplex_types() || init_env()
+		|| lam_init_onesided() || init_f77()) {
+	    return(lam_errfunc(LAM_MPI_C_COMM_NULL,
+		    BLKMPIINIT, lam_mkerr(MPI_ERR_OTHER, errno)));
 	}
 
 	lam_ports_init();
@@ -485,7 +481,8 @@ init_comm(void)
  * communicators.
  */
 	cid = lam_getcid();
-	if (lam_comm_new(cid, group, MPI_GROUP_NULL, LAM_PREDEF, &comm)) {
+	if (lam_comm_new(cid, group, LAM_MPI_C_GROUP_NULL,
+			 LAM_PREDEF, &comm)) {
 		return(LAMERROR);
 	}
 	
@@ -625,11 +622,48 @@ init_dtype(void)
 		   LAM_ALIGNMENT_FLOAT, TRDTFREAL, "MPI_REAL");
 	make_dtype(MPI_F_DOUBLE_PRECISION, sizeof(double),
 		   LAM_ALIGNMENT_DOUBLE, TRDTFDBLPREC, "MPI_DOUBLE_PRECISION");
-	make_dtype(MPI_F_COMPLEX, 2 * sizeof(float),
-		   LAM_ALIGNMENT_FLOAT, TRDTFCOMPLEX, "MPI_COMPLEX");
-	make_dtype(MPI_F_DOUBLE_COMPLEX, 2 * sizeof(double),
-		   LAM_ALIGNMENT_DOUBLE, TRDTFDBLCOMPLEX, 
-		   "MPI_DOUBLE_COMPLEX");
+}
+
+/*
+ *	init_fcomplex_types
+ *
+ *	Function:	- initialize the FORTRAN complex datatypes
+ *	Returns:	- 0 or LAMERROR
+ */
+static int
+init_fcomplex_types(void)
+{
+	MPI_Datatype	newdtype;
+	int		err;
+/*
+ * Create MPI_COMPLEX.
+ */
+	err = MPI_Type_contiguous(2, MPI_F_REAL, &newdtype);
+	if (err != MPI_SUCCESS) 
+	    return(LAMERROR);
+
+	memcpy((char *)MPI_F_COMPLEX, (char *)newdtype, sizeof(struct _dtype));
+	free((char *)newdtype);
+	MPI_F_COMPLEX->dt_label = TRDTFCOMPLEX;
+	MPI_F_COMPLEX->dt_commit = 1;
+	MPI_F_COMPLEX->dt_flags |= LAM_PREDEF;
+	strcpy(MPI_F_COMPLEX->dt_name, "MPI_COMPLEX");
+/*
+ * Create MPI_DOUBLE_COMPLEX.
+ */
+	err = MPI_Type_contiguous(2, MPI_F_DOUBLE_PRECISION, &newdtype);
+	if (err != MPI_SUCCESS) 
+	    return(LAMERROR);
+
+	memcpy((char *)MPI_F_DOUBLE_COMPLEX, (char *)newdtype,
+		sizeof(struct _dtype));
+	free((char *)newdtype);
+	MPI_F_DOUBLE_COMPLEX->dt_label = TRDTFDBLCOMPLEX;
+	MPI_F_DOUBLE_COMPLEX->dt_commit = 1;
+	MPI_F_DOUBLE_COMPLEX->dt_flags |= LAM_PREDEF;
+	strcpy(MPI_F_DOUBLE_COMPLEX->dt_name, "MPI_DOUBLE_COMPLEX");
+
+	return(0);
 }
 
 /*
@@ -860,31 +894,37 @@ init_env(void)
 /*
  * Create the predefined keys for MPI_COMM_WORLD.
  */
-	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
+	err = MPI_Comm_create_keyval(LAM_MPI_C_NULL_COPY_FN, 
+				     LAM_MPI_C_NULL_DELETE_FN,
 				     &key, (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_TAG_UB)) return(LAMERROR);
 
-	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
+	err = MPI_Comm_create_keyval(LAM_MPI_C_NULL_COPY_FN,
+				     LAM_MPI_C_NULL_DELETE_FN,
 				     &key, (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_HOST)) return(LAMERROR);
 
-	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
+	err = MPI_Comm_create_keyval(LAM_MPI_C_NULL_COPY_FN,
+				     LAM_MPI_C_NULL_DELETE_FN,
 				     &key, (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_IO)) return(LAMERROR);
 
-	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
+	err = MPI_Comm_create_keyval(LAM_MPI_C_NULL_COPY_FN, 
+				     LAM_MPI_C_NULL_DELETE_FN,
 				     &key, (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_WTIME_IS_GLOBAL)) {
 		return(LAMERROR);
 	}
 
-	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
+	err = MPI_Comm_create_keyval(LAM_MPI_C_NULL_COPY_FN, 
+				     LAM_MPI_C_NULL_DELETE_FN,
 				     &key, (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_UNIVERSE_SIZE)) {
 		return(LAMERROR);
 	}
 
-	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
+	err = MPI_Comm_create_keyval(LAM_MPI_C_NULL_COPY_FN, 
+				     LAM_MPI_C_NULL_DELETE_FN,
 				     &key, (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_APPNUM)) {
 		return(LAMERROR);
@@ -892,18 +932,18 @@ init_env(void)
 /*
  * Create the predefined keys for windows.
  */
-	err = MPI_Win_create_keyval(MPI_C_WIN_NULL_COPY_FN,
-				    MPI_C_WIN_NULL_DELETE_FN, &key, 
+	err = MPI_Win_create_keyval(LAM_MPI_C_WIN_NULL_COPY_FN,
+				    LAM_MPI_C_WIN_NULL_DELETE_FN, &key, 
 				    (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_WIN_BASE)) return(LAMERROR);
 
-	err = MPI_Win_create_keyval(MPI_C_WIN_NULL_COPY_FN,
-				    MPI_C_WIN_NULL_DELETE_FN, &key, 
+	err = MPI_Win_create_keyval(LAM_MPI_C_WIN_NULL_COPY_FN,
+				    LAM_MPI_C_WIN_NULL_DELETE_FN, &key, 
 				    (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_WIN_SIZE)) return(LAMERROR);
 
-	err = MPI_Win_create_keyval(MPI_C_WIN_NULL_COPY_FN,
-				    MPI_C_WIN_NULL_DELETE_FN, &key, 
+	err = MPI_Win_create_keyval(LAM_MPI_C_WIN_NULL_COPY_FN,
+				    LAM_MPI_C_WIN_NULL_DELETE_FN, &key, 
 				    (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_WIN_DISP_UNIT)) {
 		return(LAMERROR);
@@ -911,19 +951,21 @@ init_env(void)
 /* 
  * Make the predefined keys for IMPI attributes
  */
-	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
+	err = MPI_Comm_create_keyval(LAM_MPI_C_NULL_COPY_FN, 
+				     LAM_MPI_C_NULL_DELETE_FN,
 				     &key, (void *) 0);
 	if ((err != MPI_SUCCESS) || (key != IMPI_CLIENT_SIZE)) 
 	  return LAMERROR;
-	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
+	err = MPI_Comm_create_keyval(LAM_MPI_C_NULL_COPY_FN, 
+				     LAM_MPI_C_NULL_DELETE_FN,
 				     &key, (void *) 0);
 	if ((err != MPI_SUCCESS) || (key != IMPI_CLIENT_COLOR)) 
 	  return LAMERROR;
-	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
+	err = MPI_Comm_create_keyval(LAM_MPI_C_NULL_COPY_FN, LAM_MPI_C_NULL_DELETE_FN,
 				     &key, (void *) 0);
 	if ((err != MPI_SUCCESS) || (key != IMPI_HOST_SIZE)) 
 	  return LAMERROR;
-	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
+	err = MPI_Comm_create_keyval(LAM_MPI_C_NULL_COPY_FN, LAM_MPI_C_NULL_DELETE_FN,
 				     &key, (void *) 0);
 	if ((err != MPI_SUCCESS) || (key != IMPI_HOST_COLOR)) 
 	  return LAMERROR;
@@ -1298,7 +1340,7 @@ init_f77(void)
 	MPI_COMM_SELF->c_group->g_f77handle = lam_F_nhdl;
 	lam_F_handles[lam_F_nhdl++] = MPI_COMM_SELF->c_group;
 /*
- * The C basic types are also registered to allow user of the F77 handle
+ * The C basic types are also registered to allow use of the F77 handle
  * as an integer type identifier in one-sided communication.
  */
 	MPI_CHAR->dt_f77handle = lam_F_nhdl;
