@@ -1,6 +1,6 @@
 /*
  * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
  *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
  * 
  * This file is part of the Notre Dame LAM implementation of MPI.
@@ -10,18 +10,21 @@
  * LICENSE.  If not, contact Office of Research, University of Notre
  * Dame, Notre Dame, IN 46556.
  * 
- * Permission to modify the code and to distribute modified code is
- * granted, provided the text of this NOTICE is retained, a notice that
- * the code was modified is included with the above COPYRIGHT NOTICE and
- * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
- * file is distributed with the modified code.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted subject to the conditions specified in the
+ * LICENSE file.
  * 
- * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
- * By way of example, but not limitation, Licensor MAKES NO
- * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
- * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
- * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
+ * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+ * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
+ * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
+ * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  * 
  * Additional copyrights may follow.
  * 
@@ -29,7 +32,7 @@
  *	Copyright 1997 The Ohio State University
  *	NJN
  *
- *	$Id: shm_common.c,v 1.3 2001/02/15 20:48:59 jsquyres Exp $
+ *	$Id: shm_common.c,v 1.3.2.2 2001/10/12 00:39:23 bbarrett Exp $
  *
  *	Function:	- common shared memory transport low-level routines
  */
@@ -106,7 +109,7 @@ union header {
 	unsigned int    ptr;		/* next block offset if on free list */
 	unsigned int	size;		/* size of this block */
     } s;
-    char align[ALIGNMENT];		/* alignment */
+    char align[LAM_ALIGNMENT];		/* alignment */
 };
 
 typedef union header 	shm_header_t;
@@ -711,7 +714,7 @@ shminit(void *memory, unsigned int nbytes, int first)
 {
 	int		nunits;
 	
-	nunits = nbytes >> LOG_ALIGN;
+	nunits = nbytes >> LAM_LOG_ALIGN;
 
 	freelist = memory;
 	poolbase = memory;
@@ -750,11 +753,11 @@ lam_shmalloc(unsigned int *nbytes, int *offset)
 /*
  * Round allocation request down to maximum allowed.
  */
-    nunits = (*nbytes + sizeof(shm_header_t) - 1) >> LOG_ALIGN;
+    nunits = (*nbytes + sizeof(shm_header_t) - 1) >> LAM_LOG_ALIGN;
 
     if (nunits > _shm_maxalloc) {
         nunits = _shm_maxalloc;
-        *nbytes = _shm_maxalloc << LOG_ALIGN;
+        *nbytes = _shm_maxalloc << LAM_LOG_ALIGN;
     }
 /*
  * One extra unit for the header.
